@@ -39,6 +39,7 @@
 
 pthread_mutex_t rcu_copy_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+static
 void rcu_copy_mutex_lock(void)
 {
 	int ret;
@@ -49,6 +50,7 @@ void rcu_copy_mutex_lock(void)
 	}
 }
 
+static
 void rcu_copy_mutex_unlock(void)
 {
 	int ret;
@@ -83,9 +85,10 @@ static int num_write;
 static caa_cycles_t __attribute__((aligned(CAA_CACHE_LINE_SIZE))) *reader_time;
 static caa_cycles_t __attribute__((aligned(CAA_CACHE_LINE_SIZE))) *writer_time;
 
+static
 void *thr_reader(void *arg)
 {
-	int i, j;
+	unsigned int i, j;
 	struct test_array *local_ptr;
 	caa_cycles_t time1, time2;
 
@@ -119,9 +122,10 @@ void *thr_reader(void *arg)
 
 }
 
+static
 void *thr_writer(void *arg)
 {
-	int i, j;
+	unsigned int i, j;
 	struct test_array *new, *old;
 	caa_cycles_t time1, time2;
 
